@@ -63,6 +63,9 @@ struct _TangleActorPrivate {
 	TangleAction* leave_action;
 	TangleAction* motion_action;
 	TangleAction* scroll_action;
+	TangleAction* hide_action;
+	TangleAction* show_action;
+	TangleAction* show_completed_action;
 	TangleAction* transition_completed_action;
 	
 	GList* ancestor_events;
@@ -116,11 +119,15 @@ enum {
 	PROP_LEAVE_ACTION,
 	PROP_MOTION_ACTION,
 	PROP_SCROLL_ACTION,
+	PROP_HIDE_ACTION,
+	PROP_SHOW_ACTION,
+	PROP_SHOW_COMPLETED_ACTION,
 	PROP_TRANSITION_COMPLETED_ACTION
 };
 
 enum {
 	ANIMATE_TRANSITION,
+	SHOW_COMPLETED,
 	TRANSITION_COMPLETED,
 	LAST_SIGNAL
 };
@@ -879,9 +886,25 @@ static void tangle_actor_pick(ClutterActor* clutter_actor, const ClutterColor* c
 	}
 }
 
+static void tangle_actor_real_show(ClutterActor* clutter_actor) {
+	TangleActor* actor;
+	TangleProperties* properties;
+	
+	actor = TANGLE_ACTOR(clutter_actor);
+
+	CLUTTER_ACTOR_CLASS(tangle_actor_parent_class)->show(clutter_actor);
+
+	if (actor->priv->show_action) {
+		properties = tangle_properties_new();
+		tangle_action_execute_full(actor->priv->show_action, G_OBJECT(actor), "show", properties);
+		g_object_unref(G_OBJECT(properties));
+	}
+}
+
 static void tangle_actor_hide(ClutterActor* clutter_actor) {
 	TangleActor* actor;
 	ClutterActorBox box = { 0.0, 0.0, 0.0, 0.0 };
+	TangleProperties* properties;
 	
 	actor = TANGLE_ACTOR(clutter_actor);
 
@@ -898,6 +921,12 @@ static void tangle_actor_hide(ClutterActor* clutter_actor) {
 		g_object_unref(actor->priv->hiding_animation);
 		actor->priv->hiding_animation = NULL;
 	}
+
+	if (actor->priv->hide_action) {
+		properties = tangle_properties_new();
+		tangle_action_execute_full(actor->priv->hide_action, G_OBJECT(actor), "hide", properties);
+		g_object_unref(G_OBJECT(properties));
+	}
 	
 	CLUTTER_ACTOR_CLASS(tangle_actor_parent_class)->hide(clutter_actor);
 }
@@ -1042,6 +1071,18 @@ static void tangle_actor_transition_completed(TangleActor* actor, ClutterActorBo
 	
 }
 
+static void tangle_actor_show_completed(TangleActor* actor, ClutterActorBox* current_box) {
+	TangleProperties* properties;
+	
+	if (actor->priv->show_completed_action) {
+		properties = tangle_properties_new();
+		tangle_properties_set(properties, "current-allocation", CLUTTER_TYPE_ACTOR_BOX, current_box, NULL);
+		tangle_action_execute_full(actor->priv->show_completed_action, G_OBJECT(actor), "show-completed", properties);
+		g_object_unref(G_OBJECT(properties));
+	}
+	
+}
+
 static void tangle_actor_paint_event_handler(ClutterActor* self, gpointer user_data) {
 	TangleActor* actor;
 
@@ -1160,6 +1201,15 @@ static void tangle_actor_set_property(GObject* object, guint prop_id, const GVal
 		case PROP_SCROLL_ACTION:
 			SET_ACTION(scroll_action);
 			break;
+		case PROP_HIDE_ACTION:
+			SET_ACTION(hide_action);
+			break;
+		case PROP_SHOW_ACTION:
+			SET_ACTION(show_action);
+			break;
+		case PROP_SHOW_COMPLETED_ACTION:
+			SET_ACTION(show_completed_action);
+			break;
 		case PROP_TRANSITION_COMPLETED_ACTION:
 			SET_ACTION(transition_completed_action);
 			break;
@@ -1237,6 +1287,15 @@ static void tangle_actor_get_property(GObject* object, guint prop_id, GValue* va
 		case PROP_SCROLL_ACTION:
 			g_value_set_object(value, actor->priv->scroll_action);
 			break;
+		case PROP_HIDE_ACTION:
+			g_value_set_object(value, actor->priv->hide_action);
+			break;
+		case PROP_SHOW_ACTION:
+			g_value_set_object(value, actor->priv->show_action);
+			break;
+		case PROP_SHOW_COMPLETED_ACTION:
+			g_value_set_object(value, actor->priv->show_completed_action);
+			break;
 		case PROP_TRANSITION_COMPLETED_ACTION:
 			g_value_set_object(value, actor->priv->transition_completed_action);
 			break;
@@ -1281,6 +1340,7 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 	clutter_actor_class->allocate = tangle_actor_allocate;
 	clutter_actor_class->paint = tangle_actor_paint;
 	clutter_actor_class->pick = tangle_actor_pick;
+	clutter_actor_class->show = tangle_actor_real_show;
 	clutter_actor_class->hide = tangle_actor_hide;
 	clutter_actor_class->button_press_event = tangle_actor_button_press_event;
 	clutter_actor_class->button_release_event = tangle_actor_button_press_event;
@@ -1291,6 +1351,7 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 	
 	actor_class->animate_transition = tangle_actor_animate_transition;
 	actor_class->transition_completed = tangle_actor_transition_completed;
+	actor_class->show_completed = tangle_actor_show_completed;
 	actor_class->handle_ancestor_event = tangle_actor_real_handle_ancestor_event;
 	actor_class->handle_descendant_event = tangle_actor_real_handle_descendant_event;
 
@@ -1462,7 +1523,7 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 	                                TANGLE_TYPE_ACTION,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
-	 * TangleActor:button-press-action:
+	 * TangleActor:button-release-action:
 	 */
 	g_object_class_install_property(gobject_class, PROP_BUTTON_RELEASE_ACTION,
 	                                g_param_spec_object("button-release-action",
@@ -1471,7 +1532,7 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 	                                TANGLE_TYPE_ACTION,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
-	 * TangleActor:button-press-action:
+	 * TangleActor:enter-action:
 	 */
 	g_object_class_install_property(gobject_class, PROP_ENTER_ACTION,
 	                                g_param_spec_object("enter-action",
@@ -1480,7 +1541,7 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 	                                TANGLE_TYPE_ACTION,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
-	 * TangleActor:button-press-action:
+	 * TangleActor:leave-action:
 	 */
 	g_object_class_install_property(gobject_class, PROP_LEAVE_ACTION,
 	                                g_param_spec_object("leave-action",
@@ -1489,7 +1550,7 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 	                                TANGLE_TYPE_ACTION,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
-	 * TangleActor:button-press-action:
+	 * TangleActor:motion-action:
 	 */
 	g_object_class_install_property(gobject_class, PROP_MOTION_ACTION,
 	                                g_param_spec_object("motion-action",
@@ -1498,7 +1559,7 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 	                                TANGLE_TYPE_ACTION,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
-	 * TangleActor:button-press-action:
+	 * TangleActor:scroll-action:
 	 */
 	g_object_class_install_property(gobject_class, PROP_SCROLL_ACTION,
 	                                g_param_spec_object("scroll-action",
@@ -1507,7 +1568,34 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 	                                TANGLE_TYPE_ACTION,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
-	 * TangleActor:animation-completed-action:
+	 * TangleActor:hide-action:
+	 */
+	g_object_class_install_property(gobject_class, PROP_HIDE_ACTION,
+	                                g_param_spec_object("hide-action",
+	                                "Hide action",
+	                                "The action that correspond to the hide signal",
+	                                TANGLE_TYPE_ACTION,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleActor:show-action:
+	 */
+	g_object_class_install_property(gobject_class, PROP_SHOW_ACTION,
+	                                g_param_spec_object("show-action",
+	                                "Show action",
+	                                "The action that correspond to the show signal",
+	                                TANGLE_TYPE_ACTION,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleActor:show-completed-action:
+	 */
+	g_object_class_install_property(gobject_class, PROP_SHOW_ACTION,
+	                                g_param_spec_object("show-completed-action",
+	                                "Show completed action",
+	                                "The action that correspond to the show-completed signal",
+	                                TANGLE_TYPE_ACTION,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleActor:transition-completed-action:
 	 */
 	g_object_class_install_property(gobject_class, PROP_TRANSITION_COMPLETED_ACTION,
 	                                g_param_spec_object("transition-completed-action",
@@ -1530,6 +1618,19 @@ static void tangle_actor_class_init(TangleActorClass* actor_class) {
 						   tangle_marshal_OBJECT__BOXED_BOXED,
 						   CLUTTER_TYPE_ANIMATION, 2,
 						   CLUTTER_TYPE_ACTOR_BOX, CLUTTER_TYPE_ACTOR_BOX);
+	/**
+	 * TangleActor::show-completed:
+	 * @actor: the object which received the signal
+	 *
+	 * The ::show-completed signal is emitted when the transition animation (see ::animate-transition), that is related
+	 * to showing, is completed, or immediately if there is no animation.
+	 */
+	signals[SHOW_COMPLETED] = g_signal_new("show-completed", G_TYPE_FROM_CLASS(gobject_class),
+	                                             G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET(TangleActorClass, show_completed),
+						     NULL, NULL,
+						     g_cclosure_marshal_VOID__BOXED,
+						     G_TYPE_NONE, 1,
+						     CLUTTER_TYPE_ACTOR_BOX);
 	/**
 	 * TangleActor::transition-completed:
 	 * @actor: the object which received the signal
@@ -1598,6 +1699,9 @@ static void on_transition_animation_completed(ClutterAnimation* animation, gpoin
 	vault = TANGLE_VAULT(user_data);
 	tangle_vault_get(vault, 3, TANGLE_TYPE_ACTOR, &actor, CLUTTER_TYPE_ACTOR_BOX, &from_allocation, CLUTTER_TYPE_ACTOR_BOX, &to_allocation);
 	g_signal_emit(actor, signals[TRANSITION_COMPLETED], 0, from_allocation, to_allocation);
+	if (!from_allocation) {
+		g_signal_emit(actor, signals[SHOW_COMPLETED], 0, to_allocation);
+	}
 }
 
 static ClutterAnimation* animate_transition(TangleActor* actor, ClutterActorBox* from_allocation, ClutterActorBox* to_allocation) {
@@ -1610,6 +1714,9 @@ static ClutterAnimation* animate_transition(TangleActor* actor, ClutterActorBox*
 		tangle_signal_connect_vault(animation, "completed", G_CALLBACK(on_transition_animation_completed), vault);
 	} else {
 		g_signal_emit(actor, signals[TRANSITION_COMPLETED], 0, from_allocation, to_allocation);
+		if (!from_allocation) {
+			g_signal_emit(actor, signals[SHOW_COMPLETED], 0, to_allocation);
+		}
 	}
 
 	return animation;
