@@ -23,7 +23,8 @@ enum {
 	PROP_FLOATING_MODE_DRAGGED,
 	PROP_PLACEHOLDER_OPACITY_DRAGGED,
 	PROP_DRAGGING_THRESHOLD_X,
-	PROP_DRAGGING_THRESHOLD_Y
+	PROP_DRAGGING_THRESHOLD_Y,
+	PROP_USE_ANCHOR_POINT
 };
 
 enum {
@@ -43,6 +44,7 @@ struct _TangleDraggableActorPrivate {
 	gulong captured_event_handler_id;
 	guint dragging_effective : 1;
 	guint descendant_interacting : 1;
+	guint use_anchor_point : 1;
 };
 
 static guint signals[LAST_SIGNAL] = { 0 };
@@ -180,6 +182,7 @@ static gboolean tangle_draggable_actor_button_press_event(ClutterActor* actor, C
 	TangleDraggableActor* draggable_actor;
 	gboolean handled;
 	gfloat x, y;
+	gfloat width, height;
 	
 	draggable_actor = TANGLE_DRAGGABLE_ACTOR(actor);
 	
@@ -191,6 +194,9 @@ static gboolean tangle_draggable_actor_button_press_event(ClutterActor* actor, C
 	draggable_actor->priv->dragging->anchor_y = event->y - y;
 	draggable_actor->priv->dragging->dx = event->x - x - draggable_actor->priv->dragging->anchor_x;
 	draggable_actor->priv->dragging->dy = event->y - y - draggable_actor->priv->dragging->anchor_y;
+	clutter_actor_get_size(actor, &width, &height);
+	draggable_actor->priv->dragging->center_x = x + width / 2;
+	draggable_actor->priv->dragging->center_y = y + height / 2;
 
 	draggable_actor->priv->dragging_effective = FALSE;
 	draggable_actor->priv->captured_event_handler_id = g_signal_connect(clutter_actor_get_stage(actor), "captured-event", G_CALLBACK(on_captured_event), actor);
@@ -231,6 +237,9 @@ static void tangle_draggable_actor_set_property(GObject* object, guint prop_id,
 		case PROP_DRAGGING_THRESHOLD_Y:
 			tangle_draggable_actor_set_dragging_threshold_y(draggable_actor, g_value_get_float(value));
 			break;
+		case PROP_USE_ANCHOR_POINT:
+			draggable_actor->priv->use_anchor_point = g_value_get_boolean(value);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -249,6 +258,9 @@ static void tangle_draggable_actor_get_property(GObject* object, guint prop_id,
 		case PROP_DRAGGING_THRESHOLD_Y:
 			g_value_set_float(value, draggable_actor->priv->dragging_threshold_y);
 			break;
+		case PROP_USE_ANCHOR_POINT:
+			g_value_set_boolean(value, draggable_actor->priv->use_anchor_point);
+			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -299,6 +311,17 @@ static void tangle_draggable_actor_class_init(TangleDraggableActorClass* draggab
 	                                                    "The vertical threshold before dragging starts",
 	                                                   -G_MAXFLOAT, G_MAXFLOAT, 0.0,
 	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleDraggableActor:use-anchor-point:
+	 *
+	 * Whether to use anchor (touch) point or center point as a reference when checking droppable area.
+	 */
+	g_object_class_install_property(gobject_class, PROP_DRAGGING_THRESHOLD_Y,
+	                                g_param_spec_boolean("use-anchor-point",
+	                                                     "Use anchor point",
+	                                                     "Whether to use anchor (touch) point or center point as a reference",
+	                                                     FALSE,
+	                                                     G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	/**
 	 * TangleDraggableActor::begin-dragging:
@@ -350,14 +373,20 @@ static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpoi
 	TangleDraggableActor* draggable_actor;
 	gboolean handled = TRUE;
 	gfloat x, y;
+	gfloat width, height;
 	
 	if (event->type == CLUTTER_MOTION || event->type == CLUTTER_BUTTON_RELEASE) {
 		draggable_actor = TANGLE_DRAGGABLE_ACTOR(user_data);
+		
+		g_object_ref(draggable_actor);
 
 		clutter_event_get_coords(event, &draggable_actor->priv->dragging->x, &draggable_actor->priv->dragging->y);
 		clutter_actor_get_transformed_position(CLUTTER_ACTOR(draggable_actor), &x, &y);
 		draggable_actor->priv->dragging->dx = draggable_actor->priv->dragging->x - x - draggable_actor->priv->dragging->anchor_x;
 		draggable_actor->priv->dragging->dy = draggable_actor->priv->dragging->y - y - draggable_actor->priv->dragging->anchor_y;
+		clutter_actor_get_size(CLUTTER_ACTOR(draggable_actor), &width, &height);
+		draggable_actor->priv->dragging->center_x = x + width / 2 + draggable_actor->priv->dragging->dx;
+		draggable_actor->priv->dragging->center_y = y + height / 2 + draggable_actor->priv->dragging->dy;
 
 		if (draggable_actor->priv->dragging_effective) {
 			handle_droppable_actor(draggable_actor->priv->dragging);
@@ -388,6 +417,8 @@ static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpoi
 				g_signal_handler_disconnect(actor, draggable_actor->priv->captured_event_handler_id);
 			}
 		}
+
+		g_object_unref(draggable_actor);
 	}
 
 	return FALSE;
@@ -415,7 +446,11 @@ static void handle_droppable_actor(TangleDragging* dragging) {
 	ClutterActor* actor;
 	TangleDroppableActor* droppable_actor;
 	
-	actor = clutter_stage_get_actor_at_pos(CLUTTER_STAGE(clutter_actor_get_stage(CLUTTER_ACTOR(dragging->draggable_actor))), CLUTTER_PICK_ALL, dragging->x, dragging->y);
+	if (dragging->draggable_actor->priv->use_anchor_point) {
+		actor = clutter_stage_get_actor_at_pos(CLUTTER_STAGE(clutter_actor_get_stage(CLUTTER_ACTOR(dragging->draggable_actor))), CLUTTER_PICK_ALL, dragging->x, dragging->y);
+	} else {
+		actor = clutter_stage_get_actor_at_pos(CLUTTER_STAGE(clutter_actor_get_stage(CLUTTER_ACTOR(dragging->draggable_actor))), CLUTTER_PICK_ALL, dragging->center_x, dragging->center_y);
+	}
 	droppable_actor = get_droppable_actor_from_hierarchy(actor);
 	if (dragging->droppable_actor != droppable_actor) {
 		if (dragging->droppable_actor) {
