@@ -259,7 +259,6 @@ static void tangle_floating_actor_get_preferred_height(TangleActor* actor, gfloa
 	}
 }
 
-
 static void tangle_floating_actor_allocate_wrapped(TangleWrapperActor* wrapper_actor, ClutterActor* wrapped, const ClutterActorBox* box, ClutterAllocationFlags flags) {
 	if (TANGLE_FLOATING_ACTOR(wrapper_actor)->priv->floating_mode != TANGLE_FLOATING_MODE_COLLAPSE) {
 		clutter_actor_allocate(wrapped, box, flags);
@@ -284,6 +283,12 @@ static void tangle_floating_actor_set_property(GObject* object, guint prop_id, c
 		case PROP_FLOATING_SCALE_Y:
 			tangle_floating_actor_set_floating_scale_y(floating_actor, g_value_get_float(value));
 			break;
+		case PROP_FLOATING_SCALE_CENTER_X:
+			tangle_floating_actor_set_floating_scale_center_x(floating_actor, g_value_get_float(value));
+			break;
+		case PROP_FLOATING_SCALE_CENTER_Y:
+			tangle_floating_actor_set_floating_scale_center_y(floating_actor, g_value_get_float(value));
+			break;
 		case PROP_PLACEHOLDER_OPACITY:
 			tangle_floating_actor_set_placeholder_opacity(floating_actor, g_value_get_uchar(value));
 			break;
@@ -311,6 +316,12 @@ static void tangle_floating_actor_get_property(GObject* object, guint prop_id, G
 		case PROP_FLOATING_SCALE_Y:
 			g_value_set_float(value, floating_actor->priv->floating_scale_y);
 			break;
+		case PROP_FLOATING_SCALE_CENTER_X:
+			g_value_set_float(value, floating_actor->priv->floating_scale_x);
+			break;
+		case PROP_FLOATING_SCALE_CENTER_Y:
+			g_value_set_float(value, floating_actor->priv->floating_scale_y);
+			break;
 		case PROP_PLACEHOLDER_OPACITY:
 			g_value_set_uchar(value, floating_actor->priv->placeholder_opacity);
 			break;
@@ -400,6 +411,24 @@ static void tangle_floating_actor_class_init(TangleFloatingActorClass* floating_
 	                                                    "The floating scaling along y axis",
 	                                                   -G_MAXFLOAT, G_MAXFLOAT, 1.0,
 	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleFloatingActor:floating-sacale-center-x
+	 */
+	g_object_class_install_property(gobject_class, PROP_FLOATING_SCALE_CENTER_X,
+	                                g_param_spec_float("floating-scale-center-x",
+	                                                    "Floating scale center X",
+	                                                    "The center point of floating scale in X axis",
+	                                                   -G_MAXFLOAT, G_MAXFLOAT, 1.0,
+	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleFloatingActor:floating-scale-center-y
+	 */
+	g_object_class_install_property(gobject_class, PROP_FLOATING_SCALE_CENTER_Y,
+	                                g_param_spec_float("floating-scale-center-y",
+	                                                    "Floating scale center Y",
+	                                                    "The center point of floating scale in Y axis",
+	                                                   -G_MAXFLOAT, G_MAXFLOAT, 1.0,
+	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	/**
 	 * TangleFloatingActor:placeholder-opacity
 	 */
