@@ -96,6 +96,7 @@ void tangle_scrolling_actor_set_scrolling_offset_y(TangleScrollingActor* scrolli
 }
 
 gfloat tangle_scrolling_actor_get_scrolling_width(TangleScrollingActor* scrolling_actor) {
+
 	return scrolling_actor->priv->scrolling_width;
 }
 
@@ -134,9 +135,8 @@ static gboolean tangle_scrolling_actor_button_press_event(ClutterActor* actor, C
 		
 	scrolling_actor = TANGLE_SCROLLING_ACTOR(actor);
 
-	clutter_actor_get_transformed_position(actor, &x, &y);
-	scrolling_actor->priv->start_motion_x = x + event->x;
-	scrolling_actor->priv->start_motion_y = y + event->y;
+	scrolling_actor->priv->start_motion_x = event->x;
+	scrolling_actor->priv->start_motion_y = event->y;
 	scrolling_actor->priv->start_scrolling_offset_x = scrolling_actor->priv->scrolling_offset_x;
 	scrolling_actor->priv->start_scrolling_offset_y = scrolling_actor->priv->scrolling_offset_y;
 	scrolling_actor->priv->scrolling_effective = FALSE;
@@ -148,12 +148,20 @@ static gboolean tangle_scrolling_actor_button_press_event(ClutterActor* actor, C
 
 static void tangle_scrolling_actor_allocate_wrapped(TangleWrapperActor* wrapper_actor, ClutterActor* wrapped, const ClutterActorBox* box, ClutterAllocationFlags flags) {
 	TangleScrollingActor* scrolling_actor;
-	gfloat x, y;
+	gfloat old_width, old_height;
 	ClutterActorBox actor_box;
 
 	scrolling_actor = TANGLE_SCROLLING_ACTOR(wrapper_actor);
 
+	old_width = scrolling_actor->priv->scrolling_width;
+	old_height = scrolling_actor->priv->scrolling_height;
 	clutter_actor_get_preferred_size(wrapped, NULL, NULL, &scrolling_actor->priv->scrolling_width, &scrolling_actor->priv->scrolling_height);
+	if (old_width != scrolling_actor->priv->scrolling_width) {
+		g_object_notify(G_OBJECT(wrapper_actor), "scrolling-width");
+	}
+	if (old_height != scrolling_actor->priv->scrolling_height) {
+		g_object_notify(G_OBJECT(wrapper_actor), "scrolling-height");
+	}
 
 	actor_box.x1 = box->x1 - scrolling_actor->priv->scrolling_offset_x;
 	actor_box.y1 = box->y1 - scrolling_actor->priv->scrolling_offset_y;
