@@ -55,8 +55,9 @@ void tangle_widget_foreach_type(TangleWidget* widget, GType type, ClutterCallbac
 void tangle_widget_foreach_type(TangleWidget* widget, GType type, ClutterCallback callback, gpointer user_data);
 void tangle_widget_foreach_type_swapped(TangleWidget* widget, GType type, TangleSwappedCallback swapped_callback, gpointer user_data);
 
-void tangle_widget_add_before(TangleWidget* widget, ClutterActor* actor, ClutterActor* existing, const gchar* first_property, ...) G_GNUC_NULL_TERMINATED;
-void tangle_widget_add_after(TangleWidget* widget, ClutterActor* actor, ClutterActor* existing, const gchar* first_property, ...) G_GNUC_NULL_TERMINATED;
+void tangle_widget_add(TangleWidget* widget, ClutterActor* actor, ...) G_GNUC_NULL_TERMINATED;
+void tangle_widget_add_before(TangleWidget* widget, ClutterActor* actor, ClutterActor* existing, ...) G_GNUC_NULL_TERMINATED;
+void tangle_widget_add_after(TangleWidget* widget, ClutterActor* actor, ClutterActor* existing, ...) G_GNUC_NULL_TERMINATED;
 
 void tangle_widget_set_layout(TangleWidget* widget, TangleLayout* layout);
 TangleLayout* tangle_widget_get_layout(TangleWidget* widget);
